searchNodes=[{"doc":"A implementation of RFC 6902 in pure Elixir.The patch can be a single change or a list of things that shall be changed. Therefore a list or a single JSON patch can be provided. Every patch belongs to a certain operation which influences the usage.","ref":"Jsonpatch.html","title":"Jsonpatch","type":"module"},{"doc":"Apply a Jsonpatch to a map or struct. The whole patch will not be applied when any path is invalid or any other error occured.Examplesiex&gt; patch = [ ...&gt; %Jsonpatch.Operation.Add{path: &quot;/age&quot;, value: 33}, ...&gt; %Jsonpatch.Operation.Replace{path: &quot;/hobbies/0&quot;, value: &quot;Elixir!&quot;}, ...&gt; %Jsonpatch.Operation.Replace{path: &quot;/married&quot;, value: true}, ...&gt; %Jsonpatch.Operation.Remove{path: &quot;/hobbies/1&quot;}, ...&gt; %Jsonpatch.Operation.Remove{path: &quot;/hobbies/2&quot;}, ...&gt; %Jsonpatch.Operation.Copy{from: &quot;/name&quot;, path: &quot;/surname&quot;}, ...&gt; %Jsonpatch.Operation.Move{from: &quot;/home&quot;, path: &quot;/work&quot;}, ...&gt; %Jsonpatch.Operation.Test{path: &quot;/name&quot;, value: &quot;Bob&quot;} ...&gt; ] iex&gt; target = %{&quot;name&quot; =&gt; &quot;Bob&quot;, &quot;married&quot; =&gt; false, &quot;hobbies&quot; =&gt; [&quot;Sport&quot;, &quot;Elixir&quot;, &quot;Football&quot;], &quot;home&quot; =&gt; &quot;Berlin&quot;} iex&gt; Jsonpatch.apply_patch(patch, target) %{&quot;name&quot; =&gt; &quot;Bob&quot;, &quot;married&quot; =&gt; true, &quot;hobbies&quot; =&gt; [&quot;Elixir!&quot;], &quot;age&quot; =&gt; 33, &quot;surname&quot; =&gt; &quot;Bob&quot;, &quot;work&quot; =&gt; &quot;Berlin&quot;} iex&gt; # Patch will not be applied if test fails. The target will not be changed. iex&gt; patch = [ ...&gt; %Jsonpatch.Operation.Add{path: &quot;/age&quot;, value: 33}, ...&gt; %Jsonpatch.Operation.Test{path: &quot;/name&quot;, value: &quot;Alice&quot;} ...&gt; ] iex&gt; target = %{&quot;name&quot; =&gt; &quot;Bob&quot;, &quot;married&quot; =&gt; false, &quot;hobbies&quot; =&gt; [&quot;Sport&quot;, &quot;Elixir&quot;, &quot;Football&quot;], &quot;home&quot; =&gt; &quot;Berlin&quot;} iex&gt; Jsonpatch.apply_patch(patch, target) {:error, :test_failed, &quot;Expected value &#39;Alice&#39; at &#39;/name&#39;&quot;}","ref":"Jsonpatch.html#apply_patch/2","title":"Jsonpatch.apply_patch/2","type":"function"},{"doc":"Creates &quot;add&quot;-operations by using the keys of the destination and check their existence in the source map. Source and destination has to be parsed to a flat map.","ref":"Jsonpatch.html#create_additions/3","title":"Jsonpatch.create_additions/3","type":"function"},{"doc":"Creates &quot;remove&quot;-operations by using the keys of the destination and check their existence in the source map. Source and destination has to be parsed to a flat map.","ref":"Jsonpatch.html#create_removes/3","title":"Jsonpatch.create_removes/3","type":"function"},{"doc":"Creates &quot;replace&quot;-operations by comparing keys and values of source and destination. The source and destination map have to be flat maps.","ref":"Jsonpatch.html#create_replaces/3","title":"Jsonpatch.create_replaces/3","type":"function"},{"doc":"Creates a patch from the difference of a source map to a target map.Examplesiex&gt; source = %{&quot;name&quot; =&gt; &quot;Bob&quot;, &quot;married&quot; =&gt; false, &quot;hobbies&quot; =&gt; [&quot;Elixir&quot;, &quot;Sport&quot;, &quot;Football&quot;]} iex&gt; destination = %{&quot;name&quot; =&gt; &quot;Bob&quot;, &quot;married&quot; =&gt; true, &quot;hobbies&quot; =&gt; [&quot;Elixir!&quot;], &quot;age&quot; =&gt; 33} iex&gt; Jsonpatch.diff(source, destination) [ %Add{path: &quot;/age&quot;, value: 33}, %Replace{path: &quot;/hobbies/0&quot;, value: &quot;Elixir!&quot;}, %Replace{path: &quot;/married&quot;, value: true}, %Remove{path: &quot;/hobbies/1&quot;}, %Remove{path: &quot;/hobbies/2&quot;} ]","ref":"Jsonpatch.html#diff/2","title":"Jsonpatch.diff/2","type":"function"},{"doc":"Describe an error that occured while patching.","ref":"Jsonpatch.html#t:error/0","title":"Jsonpatch.error/0","type":"type"},{"doc":"A valid Jsonpatch operation by RFC 6902","ref":"Jsonpatch.html#t:t/0","title":"Jsonpatch.t/0","type":"type"},{"doc":"Maps JSON patches between regular Maps and list or a single Jsonpatch.Operation.","ref":"Jsonpatch.Mapper.html","title":"Jsonpatch.Mapper","type":"module"},{"doc":"Creates JSON patch struct/s from a single or list maps which represents JSON patches.Examplesiex&gt; add_patch_map = %{&quot;op&quot; =&gt; &quot;add&quot;, &quot;path&quot; =&gt; &quot;/name&quot;, &quot;value&quot; =&gt; &quot;Alice&quot;} iex&gt; Jsonpatch.Mapper.from_map(add_patch_map) %Jsonpatch.Operation.Add{path: &quot;/name&quot;, value: &quot;Alice&quot;} iex&gt; unkown_patch_map = %{&quot;op&quot; =&gt; &quot;foo&quot;, &quot;path&quot; =&gt; &quot;/name&quot;, &quot;value&quot; =&gt; &quot;Alice&quot;} iex&gt; Jsonpatch.Mapper.from_map(unkown_patch_map) {:error, :invalid}","ref":"Jsonpatch.Mapper.html#from_map/1","title":"Jsonpatch.Mapper.from_map/1","type":"function"},{"doc":"Turns JSON patches into regular map/s.Examplesiex&gt; add_patch_map = %Jsonpatch.Operation.Add{path: &quot;/name&quot;, value: &quot;Alice&quot;} iex&gt; Jsonpatch.Mapper.to_map(add_patch_map) %{op: &quot;add&quot;, path: &quot;/name&quot;, value: &quot;Alice&quot;}","ref":"Jsonpatch.Mapper.html#to_map/1","title":"Jsonpatch.Mapper.to_map/1","type":"function"},{"doc":"The Operation module is responsible for applying patches. For examples see in the available implementation from this library for this protocol:Jsonpatch.Operation.AddJsonpatch.Operation.CopyJsonpatch.Operation.MoveJsonpatch.Operation.RemoveJsonpatch.Operation.ReplaceJsonpatch.Operation.Test","ref":"Jsonpatch.Operation.html","title":"Jsonpatch.Operation","type":"protocol"},{"doc":"Executes the given patch to map/struct.","ref":"Jsonpatch.Operation.html#apply_op/2","title":"Jsonpatch.Operation.apply_op/2","type":"function"},{"doc":"","ref":"Jsonpatch.Operation.html#t:t/0","title":"Jsonpatch.Operation.t/0","type":"type"},{"doc":"The add operation is the operation for adding (as you might guess) values to a map or struct.Examplesiex&gt; add = %Jsonpatch.Operation.Add{path: &quot;/a/b&quot;, value: 1} iex&gt; target = %{&quot;a&quot; =&gt; %{&quot;c&quot; =&gt; false}} iex&gt; Jsonpatch.Operation.apply_op(add, target) %{&quot;a&quot; =&gt; %{&quot;b&quot; =&gt; 1, &quot;c&quot; =&gt; false}}","ref":"Jsonpatch.Operation.Add.html","title":"Jsonpatch.Operation.Add","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Add.html#t:t/0","title":"Jsonpatch.Operation.Add.t/0","type":"type"},{"doc":"Represents the handling of JSON patches with a copy operation.Examplesiex&gt; copy = %Jsonpatch.Operation.Copy{from: &quot;/a/b&quot;, path: &quot;/a/e&quot;} iex&gt; target = %{&quot;a&quot; =&gt; %{&quot;b&quot; =&gt; %{&quot;c&quot; =&gt; &quot;Bob&quot;}}, &quot;d&quot; =&gt; false} iex&gt; Jsonpatch.Operation.apply_op(copy, target) %{&quot;a&quot; =&gt; %{&quot;b&quot; =&gt; %{&quot;c&quot; =&gt; &quot;Bob&quot;}, &quot;e&quot; =&gt; %{&quot;c&quot; =&gt; &quot;Bob&quot;}}, &quot;d&quot; =&gt; false}","ref":"Jsonpatch.Operation.Copy.html","title":"Jsonpatch.Operation.Copy","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Copy.html#t:t/0","title":"Jsonpatch.Operation.Copy.t/0","type":"type"},{"doc":"Move operations change the position of values in map or struct.Examplesiex&gt; move = %Jsonpatch.Operation.Move{from: &quot;/a/b&quot;, path: &quot;/a/e&quot;} iex&gt; target = %{&quot;a&quot; =&gt; %{&quot;b&quot; =&gt; %{&quot;c&quot; =&gt; &quot;Bob&quot;}}, &quot;d&quot; =&gt; false} iex&gt; Jsonpatch.Operation.apply_op(move, target) %{&quot;a&quot; =&gt; %{&quot;e&quot; =&gt; %{&quot;c&quot; =&gt; &quot;Bob&quot;}}, &quot;d&quot; =&gt; false}","ref":"Jsonpatch.Operation.Move.html","title":"Jsonpatch.Operation.Move","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Move.html#t:t/0","title":"Jsonpatch.Operation.Move.t/0","type":"type"},{"doc":"A JSON patch remove operation is responsible for removing values.Examplesiex&gt; remove = %Jsonpatch.Operation.Remove{path: &quot;/a/b&quot;} iex&gt; target = %{&quot;a&quot; =&gt; %{&quot;b&quot; =&gt; %{&quot;c&quot; =&gt; &quot;Bob&quot;}}, &quot;d&quot; =&gt; false} iex&gt; Jsonpatch.Operation.apply_op(remove, target) %{&quot;a&quot; =&gt; %{}, &quot;d&quot; =&gt; false}","ref":"Jsonpatch.Operation.Remove.html","title":"Jsonpatch.Operation.Remove","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Remove.html#t:t/0","title":"Jsonpatch.Operation.Remove.t/0","type":"type"},{"doc":"The replace module helps replacing values in maps and structs by paths.Examplesiex&gt; add = %Jsonpatch.Operation.Replace{path: &quot;/a/b&quot;, value: 1} iex&gt; target = %{&quot;a&quot; =&gt; %{&quot;b&quot; =&gt; 2}} iex&gt; Jsonpatch.Operation.apply_op(add, target) %{&quot;a&quot; =&gt; %{&quot;b&quot; =&gt; 1}}","ref":"Jsonpatch.Operation.Replace.html","title":"Jsonpatch.Operation.Replace","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Replace.html#t:t/0","title":"Jsonpatch.Operation.Replace.t/0","type":"type"},{"doc":"A test operation in a JSON patch prevents the patch application or allows it.Examplesiex&gt; test = %Jsonpatch.Operation.Test{path: &quot;/x/y&quot;, value: &quot;Bob&quot;} iex&gt; target = %{&quot;x&quot; =&gt; %{&quot;y&quot; =&gt; &quot;Bob&quot;}} iex&gt; Jsonpatch.Operation.apply_op(test, target) %{&quot;x&quot; =&gt; %{&quot;y&quot; =&gt; &quot;Bob&quot;}}","ref":"Jsonpatch.Operation.Test.html","title":"Jsonpatch.Operation.Test","type":"module"},{"doc":"","ref":"Jsonpatch.Operation.Test.html#t:t/0","title":"Jsonpatch.Operation.Test.t/0","type":"type"},{"doc":"Jsonpatch A implementation of RFC 6902 in pure Elixir.Features:Creating a patch by comparing to maps and structsApply patches to maps and structs - supports operations:addreplaceremovecopymovetestDe/Encoding and mapping","ref":"readme.html","title":"Jsonpatch","type":"extras"},{"doc":"InstallationThe package can be installed by adding jsonpatch to your list of dependencies in mix.exs:def deps do [ {:jsonpatch, &quot;~&gt; 0.9.3&quot;} ] endThe docs can be found at https://hexdocs.pm/jsonpatch.Create a diffiex&gt; source = %{&quot;name&quot; =&gt; &quot;Bob&quot;, &quot;married&quot; =&gt; false, &quot;hobbies&quot; =&gt; [&quot;Sport&quot;, &quot;Elixir&quot;, &quot;Football&quot;]} iex&gt; destination = %{&quot;name&quot; =&gt; &quot;Bob&quot;, &quot;married&quot; =&gt; true, &quot;hobbies&quot; =&gt; [&quot;Elixir!&quot;], &quot;age&quot; =&gt; 33} iex&gt; Jsonpatch.diff(source, destination) {:ok, [ %Jsonpatch.Operation.Add{path: &quot;/age&quot;, value: 33}, %Jsonpatch.Operation.Replace{path: &quot;/hobbies/0&quot;, value: &quot;Elixir!&quot;}, %Jsonpatch.Operation.Replace{path: &quot;/married&quot;, value: true}, %Jsonpatch.Operation.Remove{path: &quot;/hobbies/1&quot;}, %Jsonpatch.Operation.Remove{path: &quot;/hobbies/2&quot;} ]}Mapping for de- and encodingMap a JSON patch struct to a regular map.iex&gt; add_patch_map = %Jsonpatch.Operation.Add{path: &quot;/name&quot;, value: &quot;Alice&quot;} iex&gt; Jsonpatch.Mapper.to_map(add_patch_map) %{op: &quot;add&quot;, path: &quot;/name&quot;, value: &quot;Alice&quot;}Map a regular map to a JSON patch struct.iex&gt; add_patch_map = %{&quot;op&quot; =&gt; &quot;add&quot;, &quot;path&quot; =&gt; &quot;/name&quot;, &quot;value&quot; =&gt; &quot;Alice&quot;} iex&gt; Jsonpatch.Mapper.from_map(add_patch_map) %Jsonpatch.Operation.Add{path: &quot;/name&quot;, value: &quot;Alice&quot;}Apply patchesiex&gt; patch = [ %Jsonpatch.Operation.Add{path: &quot;/age&quot;, value: 33}, %Jsonpatch.Operation.Replace{path: &quot;/hobbies/0&quot;, value: &quot;Elixir!&quot;}, %Jsonpatch.Operation.Replace{path: &quot;/married&quot;, value: true}, %Jsonpatch.Operation.Remove{path: &quot;/hobbies/1&quot;}, %Jsonpatch.Operation.Remove{path: &quot;/hobbies/2&quot;} ] iex&gt; target = %{&quot;name&quot; =&gt; &quot;Bob&quot;, &quot;married&quot; =&gt; false, &quot;hobbies&quot; =&gt; [&quot;Sport&quot;, &quot;Elixir&quot;, &quot;Football&quot;]} iex&gt; Jsonpatch.apply_patch(patch, target) %{&quot;name&quot; =&gt; &quot;Bob&quot;, &quot;married&quot; =&gt; true, &quot;hobbies&quot; =&gt; [&quot;Elixir!&quot;], &quot;age&quot; =&gt; 33}","ref":"readme.html#getting-started","title":"Jsonpatch - Getting started","type":"extras"},{"doc":"Official RFC 6902Inspiration: python-json-patch","ref":"readme.html#important-sources","title":"Jsonpatch - Important sources","type":"extras"}]